@@ -65,6 +65,8 @@ from .vtkIOVideo import *
 from .vtkIOFFMPEG import *
 from .vtkRenderingFFMPEGOpenGL2 import *
 from .vtkRenderingExternal import *
+from .vtkFiltersCellGrid import *
+from .vtkRenderingCellGrid import *
 from .vtkParallelMPI4Py import *
 from .vtkIOXdmf2 import *
 from .vtkIOVeraOut import *
@@ -90,6 +92,7 @@ from .vtkIOOpenVDB import *
 from .vtkIOOggTheora import *
 from .vtkIOOMF import *
 from .vtkIOODBC import *
+from .vtkIOOCCT import *
 from .vtkIOMySQL import *
 from .vtkIOMotionFX import *
 from .vtkIOGeometry import *
@@ -105,6 +108,7 @@ from .vtkIOH5part import *
 from .vtkIOH5Rage import *
 from .vtkIOGeoJSON import *
 from .vtkIOFides import *
+from .vtkIOFLUENTCFF import *
 from .vtkIOExportPDF import *
 from .vtkRenderingGL2PSOpenGL2 import *
 from .vtkIOExportGL2PS import *
@@ -112,6 +116,7 @@ from .vtkIOEnSight import *
 from .vtkIOCityGML import *
 from .vtkIOChemistry import *
 from .vtkIOCesium3DTiles import *
+from .vtkIOCellGrid import *
 from .vtkIOCONVERGECFD import *
 from .vtkIOHDF import *
 from .vtkIOCGNSReader import *
@@ -136,9 +141,11 @@ from .vtkRenderingAnnotation import *
 from .vtkImagingHybrid import *
 from .vtkImagingColor import *
 from .vtkFiltersTopology import *
+from .vtkFiltersTensor import *
 from .vtkFiltersSelection import *
 from .vtkFiltersSMP import *
 from .vtkFiltersReebGraph import *
+from .vtkFiltersReduction import *
 from .vtkFiltersPython import *
 from .vtkFiltersProgrammable import *
 from .vtkFiltersModeling import *
@@ -151,6 +158,7 @@ from .vtkFiltersImaging import *
 from .vtkFiltersExtraction import *
 from .vtkFiltersGeometry import *
 from .vtkFiltersHybrid import *
+from .vtkFiltersHyperTree import *
 from .vtkFiltersTexture import *
 from .vtkFiltersParallel import *
 from .vtkFiltersParallelImaging import *
@@ -158,12 +166,12 @@ from .vtkFiltersParallelGeometry import *
 from .vtkFiltersFlowPaths import *
 from .vtkFiltersParallelFlowPaths import *
 from .vtkFiltersParallelDIY2 import *
+from .vtkFiltersGeometryPreview import *
 from .vtkFiltersGeneric import *
 from .vtkFiltersAMR import *
 from .vtkDomainsParallelChemistry import *
 from .vtkFiltersParallelMPI import *
 from .vtkDomainsChemistryOpenGL2 import *
-from .vtkFiltersHyperTree import *
 from .vtkCommonPython import *
 from .vtkCommonArchive import *
 from .vtkChartsCore import *
